@@ -3,18 +3,18 @@ package v1
 import (
 	"encoding/json"
 	"errors"
+	"fmt"
 	"io/ioutil"
 	"net/http"
 
-	"go.k6.io/k6/api/common"
-	"go.k6.io/k6/lib"
+	"go.k6.io/k6/errext"
+	"go.k6.io/k6/errext/exitcodes"
+	"go.k6.io/k6/execution"
 	"go.k6.io/k6/lib/executor"
 )
 
-func handleGetStatus(rw http.ResponseWriter, r *http.Request) {
-	engine := common.GetEngine(r.Context())
-
-	status := newStatusJSONAPIFromEngine(engine)
+func handleGetStatus(cs *ControlSurface, rw http.ResponseWriter, _ *http.Request) {
+	status := newStatusJSONAPIFromEngine(cs)
 	data, err := json.Marshal(status)
 	if err != nil {
 		apiError(rw, "Encoding error", err.Error(), http.StatusInternalServerError)
@@ -24,9 +24,7 @@ func handleGetStatus(rw http.ResponseWriter, r *http.Request) {
 	_, _ = rw.Write(data)
 }
 
-func getFirstExternallyControlledExecutor(
-	execScheduler lib.ExecutionScheduler,
-) (*executor.ExternallyControlled, error) {
+func getFirstExternallyControlledExecutor(execScheduler *execution.Scheduler) (*executor.ExternallyControlled, error) {
 	executors := execScheduler.GetExecutors()
 	for _, s := range executors {
 		if mex, ok := s.(*executor.ExternallyControlled); ok {
@@ -36,9 +34,8 @@ func getFirstExternallyControlledExecutor(
 	return nil, errors.New("an externally-controlled executor needs to be configured for live configuration updates")
 }
 
-func handlePatchStatus(rw http.ResponseWriter, r *http.Request) {
+func handlePatchStatus(cs *ControlSurface, rw http.ResponseWriter, r *http.Request) {
 	rw.Header().Set("Content-Type", "application/json; charset=utf-8")
-	engine := common.GetEngine(r.Context())
 
 	body, err := ioutil.ReadAll(r.Body)
 	if err != nil {
@@ -55,10 +52,13 @@ func handlePatchStatus(rw http.ResponseWriter, r *http.Request) {
 	status := statusEnvelop.Status()
 
 	if status.Stopped { //nolint:nestif
-		engine.Stop()
+		execution.AbortTestRun(cs.RunCtx, errext.WithAbortReasonIfNone(
+			errext.WithExitCodeIfNone(fmt.Errorf("test run stopped from REST API"), exitcodes.ScriptStoppedFromRESTAPI),
+			errext.AbortedByUser,
+		))
 	} else {
 		if status.Paused.Valid {
-			if err = engine.ExecutionScheduler.SetPaused(status.Paused.Bool); err != nil {
+			if err = cs.Scheduler.SetPaused(status.Paused.Bool); err != nil {
 				apiError(rw, "Pause error", err.Error(), http.StatusInternalServerError)
 				return
 			}
@@ -68,7 +68,7 @@ func handlePatchStatus(rw http.ResponseWriter, r *http.Request) {
 			// TODO: add ability to specify the actual executor id? Though this should
 			// likely be in the v2 REST API, where we could implement it in a way that
 			// may allow us to eventually support other executor types.
-			executor, updateErr := getFirstExternallyControlledExecutor(engine.ExecutionScheduler)
+			executor, updateErr := getFirstExternallyControlledExecutor(cs.Scheduler)
 			if updateErr != nil {
 				apiError(rw, "Execution config error", updateErr.Error(), http.StatusInternalServerError)
 				return
@@ -87,7 +87,7 @@ func handlePatchStatus(rw http.ResponseWriter, r *http.Request) {
 		}
 	}
 
-	data, err := json.Marshal(newStatusJSONAPIFromEngine(engine))
+	data, err := json.Marshal(newStatusJSONAPIFromEngine(cs))
 	if err != nil {
 		apiError(rw, "Encoding error", err.Error(), http.StatusInternalServerError)
 		return
