@@ -114,6 +114,7 @@ func TestOptions(t *testing.T) {
 	t.Run("TLSCipherSuites", func(t *testing.T) {
 		t.Parallel()
 		for suiteName, suiteID := range SupportedTLSCipherSuites {
+			suiteName, suiteID := suiteName, suiteID
 			t.Run(suiteName, func(t *testing.T) {
 				t.Parallel()
 				opts := Options{}.Apply(Options{TLSCipherSuites: &TLSCipherSuites{suiteID}})
@@ -456,15 +457,18 @@ func TestOptions(t *testing.T) {
 
 	t.Run("Hosts", func(t *testing.T) {
 		t.Parallel()
-		host, err := NewHostAddress(net.ParseIP("192.0.2.1"), "80")
+		host, err := types.NewHost(net.ParseIP("192.0.2.1"), "80")
 		assert.NoError(t, err)
 
-		opts := Options{}.Apply(Options{Hosts: map[string]*HostAddress{
-			"test.loadimpact.com": host,
-		}})
+		hosts, err := types.NewNullHosts(map[string]types.Host{
+			"test.loadimpact.com": *host,
+		})
+		assert.NoError(t, err)
+		opts := Options{}.Apply(Options{Hosts: hosts})
 		assert.NotNil(t, opts.Hosts)
 		assert.NotEmpty(t, opts.Hosts)
-		assert.Equal(t, "192.0.2.1:80", opts.Hosts["test.loadimpact.com"].String())
+
+		assert.Equal(t, "192.0.2.1:80", opts.Hosts.Trie.Match("test.loadimpact.com").String())
 	})
 
 	t.Run("Throws", func(t *testing.T) {
@@ -726,21 +730,21 @@ func TestCIDRUnmarshal(t *testing.T) {
 	}
 }
 
-func TestHostAddressUnmarshal(t *testing.T) {
+func TestHost(t *testing.T) {
 	t.Parallel()
 	testData := []struct {
 		input          string
-		expectedOutput *HostAddress
+		expectedOutput *types.Host
 		expectFailure  string
 	}{
 		{
 			"1.2.3.4",
-			&HostAddress{IP: net.ParseIP("1.2.3.4")},
+			&types.Host{IP: net.ParseIP("1.2.3.4")},
 			"",
 		},
 		{
 			"1.2.3.4:80",
-			&HostAddress{IP: net.ParseIP("1.2.3.4"), Port: 80},
+			&types.Host{IP: net.ParseIP("1.2.3.4"), Port: 80},
 			"",
 		},
 		{
@@ -750,17 +754,17 @@ func TestHostAddressUnmarshal(t *testing.T) {
 		},
 		{
 			"2001:0db8:0000:0000:0000:ff00:0042:8329",
-			&HostAddress{IP: net.ParseIP("2001:0db8:0000:0000:0000:ff00:0042:8329")},
+			&types.Host{IP: net.ParseIP("2001:0db8:0000:0000:0000:ff00:0042:8329")},
 			"",
 		},
 		{
 			"2001:db8::68",
-			&HostAddress{IP: net.ParseIP("2001:db8::68")},
+			&types.Host{IP: net.ParseIP("2001:db8::68")},
 			"",
 		},
 		{
 			"[2001:db8::68]:80",
-			&HostAddress{IP: net.ParseIP("2001:db8::68"), Port: 80},
+			&types.Host{IP: net.ParseIP("2001:db8::68"), Port: 80},
 			"",
 		},
 		{
@@ -774,7 +778,7 @@ func TestHostAddressUnmarshal(t *testing.T) {
 		data := data
 		t.Run(data.input, func(t *testing.T) {
 			t.Parallel()
-			actualHost := &HostAddress{}
+			actualHost := &types.Host{}
 			err := actualHost.UnmarshalText([]byte(data.input))
 
 			if data.expectFailure != "" {
